@@ -37,6 +37,7 @@ public class XmlPmProxyReader {
         PmProxyContainer object = new PmProxyContainer();
         
         // Process the inner elements:
+        List<String[]> links = new ArrayList<>();
         reader.next();
         while (reader.forward()) {
             String name = reader.getLocalName();
@@ -45,13 +46,24 @@ public class XmlPmProxyReader {
                 object.type(XmlPmProxyTypeReader.readOne(reader));
                 break;
                 case "link":
-                readLink(reader, object);
+                // Process the attributes:
+                String rel = reader.getAttributeValue("rel");
+                String href = reader.getAttributeValue("href");
+                if (rel != null && href != null) {
+                    links.add(new String[]{rel, href});
+                }
+                reader.next();
                 break;
                 default:
                 reader.skip();
                 break;
             }
         }
+        if (links != null) {
+            for (String[] link : links) {
+                processLink(object, link);
+            }
+        }
         
         // Discard the end tag:
         reader.next();
@@ -104,26 +116,7 @@ public class XmlPmProxyReader {
         return list;
     }
     
-    private static void readLink(XmlReader reader, PmProxyContainer object) {
-        // Process the attributes:
-        String rel = null;
-        String href = null;
-        for (int i = 0; i < reader.getAttributeCount(); i++) {
-            String attrName = reader.getAttributeLocalName(i);
-            String attrVal = reader.getAttributeValue(i);
-            switch (attrName) {
-                case "href":
-                href = attrVal;
-                break;
-                case "rel":
-                rel = attrVal;
-                break;
-                default:
-                reader.skip();
-                break;
-            }
-        }
-        reader.skip();
+    private static void processLink(PmProxyContainer object, String[] link) {
     }
 }
 
