@@ -20,6 +20,7 @@ import java.io.IOException;
 import java.math.BigInteger;
 import java.net.URISyntaxException;
 import java.util.List;
+import java.util.Map;
 import org.apache.http.HttpResponse;
 import org.apache.http.client.methods.HttpGet;
 import org.apache.http.client.methods.HttpPost;
@@ -28,6 +29,7 @@ import org.apache.http.entity.ByteArrayEntity;
 import org.apache.http.util.EntityUtils;
 import org.ovirt.api.metamodel.runtime.xml.XmlReader;
 import org.ovirt.api.metamodel.runtime.xml.XmlWriter;
+import org.ovirt.engine.sdk4.BaseRequest;
 import org.ovirt.engine.sdk4.Error;
 import org.ovirt.engine.sdk4.Service;
 import org.ovirt.engine.sdk4.builders.QuotaStorageLimitBuilder;
@@ -44,7 +46,7 @@ public class QuotaStorageLimitsServiceImpl extends ServiceImpl implements QuotaS
         super(connection, path);
     }
     
-    private class AddRequestImpl implements AddRequest {
+    private class AddRequestImpl extends BaseRequest<AddRequest, AddResponse> implements AddRequest {
         private QuotaStorageLimit limit;
         public AddRequest limit(QuotaStorageLimit limit) {
             this.limit = limit;
@@ -60,6 +62,11 @@ public class QuotaStorageLimitsServiceImpl extends ServiceImpl implements QuotaS
             HttpPost request = null;
             try {
                 URIBuilder uriBuilder = new URIBuilder(getConnection().getUrl() + getPath());
+                if (query != null) {
+                    for (Map.Entry<String, String> queryParam : query.entrySet()) {
+                        uriBuilder.addParameter(queryParam.getKey(), queryParam.getValue());
+                    }
+                }
                 request = new HttpPost(uriBuilder.build());
             }
             catch (URISyntaxException ex) {
@@ -77,10 +84,17 @@ public class QuotaStorageLimitsServiceImpl extends ServiceImpl implements QuotaS
                 throw new Error("Failed to parse response", ex);
             }
             
+            if (headers != null) {
+                for (Map.Entry<String, String> header : headers.entrySet()) {
+                    request.setHeader(header.getKey(), header.getValue());
+                }
+            }
+            
             HttpResponse response = getConnection().send(request);
             if (
               response.getStatusLine().getStatusCode() == 200
               || response.getStatusLine().getStatusCode() == 201
+              || response.getStatusLine().getStatusCode() == 202
             ) {
                 try (
                   XmlReader reader = new XmlReader(response.getEntity().getContent())
@@ -119,7 +133,7 @@ public class QuotaStorageLimitsServiceImpl extends ServiceImpl implements QuotaS
         return new AddRequestImpl();
     }
     
-    private class ListRequestImpl implements ListRequest {
+    private class ListRequestImpl extends BaseRequest<ListRequest, ListResponse> implements ListRequest {
         private BigInteger max;
         public ListRequest max(BigInteger max) {
             this.max = max;
@@ -143,12 +157,23 @@ public class QuotaStorageLimitsServiceImpl extends ServiceImpl implements QuotaS
                 if (max != null) {
                     uriBuilder.addParameter("max", XmlWriter.renderInteger(max));
                 }
+                if (query != null) {
+                    for (Map.Entry<String, String> queryParam : query.entrySet()) {
+                        uriBuilder.addParameter(queryParam.getKey(), queryParam.getValue());
+                    }
+                }
                 request = new HttpGet(uriBuilder.build());
             }
             catch (URISyntaxException ex) {
                 throw new Error("Failed to build URL", ex);
             }
             
+            if (headers != null) {
+                for (Map.Entry<String, String> header : headers.entrySet()) {
+                    request.setHeader(header.getKey(), header.getValue());
+                }
+            }
+            
             HttpResponse response = getConnection().send(request);
             if (
               response.getStatusLine().getStatusCode() == 200
